==> logs-facade-1.0.0-20180425.030305-1-sources.jar: com/bxm/log/facade/dto/LogModelDto.java <==
package com.bxm.log.facade.dto;


import java.io.Serializable;
import java.util.Date;

/**
 * <h3>Shenjue.java基本描述</h3>
 * <p></p>
 *
 * @author hcmony
 * @since V1.0.0, 2018/04/23 10:49
 */
public class LogModelDto implements Serializable{


	//券状态
	public static final int STATUS = 1;
	//券预算
	public static final int BUDGET = 2;
	//券调价
	public static final int PRICE  = 3;

	/**
	 * ①区分操作人员，需要对应操作账号，广告主后台只显示广告主的操作日志（广告后台有代理商、子账号、直客三种账号）；

	 ②操作类型可筛选，券状态、券预算、券调价等；

	 ③广告主后台操作日志全部针对到广告券，可根据广告券进行对应操作日志搜索
	 */
	private static final long serialVersionUID = 2645156368705722971L;
	private String id;
	private String ip;
	private String userName;
	private String userAccount;
	private Date dateTime = new Date();
	private String content;
	private String operationType;
	private String adticketId;
	private Date startDateTime;
	private Date endDateTime;

	private Integer pageNum = 1;
	private Integer pageSize = 20;
	private String  keywords;


	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserAccount() {
		return userAccount;
	}

	public void setUserAccount(String userAccount) {
		this.userAccount = userAccount;
	}

	public Date getDateTime() {
		return dateTime;
	}

	public void setDateTime(Date dateTime) {
		if(dateTime == null){
			this.dateTime = dateTime;
		}
	}

	public String getContent() {
		return content;
	}

	public void setContent(String content) {
		this.content = content;
	}

	public String getOperationType() {
		return operationType;
	}

	public void setOperationType(String operationType) {
		this.operationType = operationType;
	}

	public String getAdticketId() {
		return adticketId;
	}

	public void setAdticketId(String adticketId) {
		this.adticketId = adticketId;
	}

	public Date getStartDateTime() {
		return startDateTime;
	}

	public void setStartDateTime(Date startDateTime) {
		this.startDateTime = startDateTime;
	}

	public Date getEndDateTime() {
		return endDateTime;
	}

	public void setEndDateTime(Date endDateTime) {
		this.endDateTime = endDateTime;
	}

	public Integer getPageNum() {
		return pageNum;
	}

	public void setPageNum(Integer pageNum) {
		if(null != pageNum){
			this.pageNum = pageNum;
		}

	}

	public Integer getPageSize() {
		return pageSize;
	}

	public void setPageSize(Integer pageSize) {
		if(null != pageSize){
			this.pageSize = pageSize;
		}
	}

	public String getKeywords() {
		return keywords;
	}

	public void setKeywords(String keywords) {
		this.keywords = keywords;
	}
}

==> logs-facade-2.0.0-sources.jar: com/bxm/log/facade/dto/LogModelDto.java <==
package com.bxm.log.facade.dto;


import java.io.Serializable;
import java.util.Date;

/**
 * <h3>Shenjue.java基本描述</h3>
 * <p></p>
 *
 * @author hcmony
 * @since V1.0.0, 2018/04/23 10:49
 */
public class LogModelDto implements Serializable{


	//券状态
	public static final int STATUS = 1;
	//券预算
	public static final int BUDGET = 2;
	//券调价
	public static final int PRICE  = 3;

	/**
	 * ①区分操作人员，需要对应操作账号，广告主后台只显示广告主的操作日志（广告后台有代理商、子账号、直客三种账号）；

	 ②操作类型可筛选，券状态、券预算、券调价等；

	 ③广告主后台操作日志全部针对到广告券，可根据广告券进行对应操作日志搜索
	 */
	private static final long serialVersionUID = 2645156368705722971L;
	private String id;
	private String ip;
	private String userName;
	private String userAccount;
	private Date dateTime = new Date();
	private String content;
	private String operationType;
	private String adticketId;
	private String adticketIds;
	private Long startDateTime;
	private Long endDateTime;

	private Integer pageNum = 1;
	private Integer pageSize = 20;
	private String  keywords;
	private String  collectionName;
	private String parentAccount;
	//日志内容,同content一样,非json格式
    private String logInfo;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserAccount() {
		return userAccount;
	}

	public void setUserAccount(String userAccount) {
		this.userAccount = userAccount;
	}

	public Date getDateTime() {
		return dateTime;
	}

	public void setDateTime(Date dateTime) {
		if(dateTime == null){
			this.dateTime = dateTime;
		}
	}

	public String getContent() {
		return content;
	}

	public void setContent(String content) {
		this.content = content;
	}

	public String getOperationType() {
		return operationType;
	}

	public void setOperationType(String operationType) {
		this.operationType = operationType;
	}

	public String getAdticketId() {
		return adticketId;
	}

	public void setAdticketId(String adticketId) {
		this.adticketId = adticketId;
	}

	public Long getStartDateTime() {

		return startDateTime;
	}

	public void setStartDateTime(Long startDateTime) {
		this.startDateTime = startDateTime;
	}

	public Long getEndDateTime() {
		return endDateTime;
	}

	public void setEndDateTime(Long endDateTime) {
		this.endDateTime = endDateTime;
	}

	public Integer getPageNum() {
		return pageNum;
	}

	public void setPageNum(Integer pageNum) {
		if(null != pageNum){
			this.pageNum = pageNum;
		}

	}

	public Integer getPageSize() {
		return pageSize;
	}

	public void setPageSize(Integer pageSize) {
		if(null != pageSize){
			this.pageSize = pageSize;
		}
	}

	public String getKeywords() {
		return keywords;
	}

	public void setKeywords(String keywords) {
		this.keywords = keywords;
	}

	public String getCollectionName() {
		if(collectionName == null){
			this.collectionName = CollectionName.ADSMANAGER;
		}
		return collectionName;
	}

	public void setCollectionName(String collectionName) {
		this.collectionName = collectionName;
	}

	public String getParentAccount() {
		return parentAccount;
	}

	public void setParentAccount(String parentAccount) {
		this.parentAccount = parentAccount;
	}

    public String getAdticketIds() {
        return adticketIds;
    }

    public void setAdticketIds(String adticketIds) {
        this.adticketIds = adticketIds;
    }

    public String getLogInfo() {
        return logInfo;
    }

    public void setLogInfo(String logInfo) {
        this.logInfo = logInfo;
    }
    
}
